==> jc-1.4.0.tar.gz: polyglot/visit/NodeScrambler.h <==
// public class polyglot.visit.NodeScrambler

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class d56530f3adaadb75 polyglot_visit_NodeScrambler
// @dep_class 534db787197439f0 polyglot_visit_NodeVisitor

// header file dependencies
// @dep_header polyglot_visit_NodeVisitor

#include "polyglot/visit/NodeVisitor.h"

#ifndef _JC_polyglot_visit_NodeScrambler_H_
#define _JC_polyglot_visit_NodeScrambler_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_HashMap$object;
struct _jc_java_util_LinkedList$object;
struct _jc_java_util_Random$object;
struct _jc_polyglot_ast_Node$object;
struct _jc_polyglot_util_CodeWriter$object;
struct _jc_polyglot_visit_NodeScrambler__24FirstPass$object;

// Typedefs
typedef struct _jc_polyglot_visit_NodeScrambler$sub_refs	_jc_polyglot_visit_NodeScrambler$sub_refs;
typedef struct _jc_polyglot_visit_NodeScrambler$sub_nonrefs	_jc_polyglot_visit_NodeScrambler$sub_nonrefs;
typedef struct _jc_polyglot_visit_NodeScrambler$refs	_jc_polyglot_visit_NodeScrambler$refs;
typedef struct _jc_polyglot_visit_NodeScrambler$nonrefs	_jc_polyglot_visit_NodeScrambler$nonrefs;
typedef struct _jc_polyglot_visit_NodeScrambler$object	_jc_polyglot_visit_NodeScrambler$object;

typedef struct _jc_polyglot_visit_NodeScrambler$fields_struct	_jc_polyglot_visit_NodeScrambler$fields_struct;
typedef const struct _jc_polyglot_visit_NodeScrambler$vmethods	_jc_polyglot_visit_NodeScrambler$vmethods;
typedef const struct _jc_polyglot_visit_NodeScrambler$vtable	_jc_polyglot_visit_NodeScrambler$vtable;
typedef const struct _jc_polyglot_visit_NodeScrambler$vtype	_jc_polyglot_visit_NodeScrambler$vtype;

// Class fields structure
struct _jc_polyglot_visit_NodeScrambler$fields_struct {
	struct _jc_java_lang_Class$object	*class__24polyglot__24ast__24Block;
	struct _jc_java_lang_Class$object	*class__24polyglot__24ast__24Catch;
	struct _jc_java_lang_Class$object	*class__24polyglot__24ast__24ClassDecl;
	struct _jc_java_lang_Class$object	*class__24polyglot__24ast__24ClassMember;
	struct _jc_java_lang_Class$object	*class__24polyglot__24ast__24Expr;
	struct _jc_java_lang_Class$object	*class__24polyglot__24ast__24Formal;
	struct _jc_java_lang_Class$object	*class__24polyglot__24ast__24Import;
	struct _jc_java_lang_Class$object	*class__24polyglot__24ast__24LocalDecl;
	struct _jc_java_lang_Class$object	*class__24polyglot__24ast__24Node;
	struct _jc_java_lang_Class$object	*class__24polyglot__24ast__24Stmt;
	struct _jc_java_lang_Class$object	*class__24polyglot__24ast__24TypeNode;
};
extern _jc_polyglot_visit_NodeScrambler$fields_struct _jc_polyglot_visit_NodeScrambler$class_fields;

// Constructors
extern void _jc_polyglot_visit_NodeScrambler$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_polyglot_visit_NodeScrambler$object *);
extern void _jc_polyglot_visit_NodeScrambler$method$_init$8de6a0a3bec04d2a(_jc_env *, struct _jc_polyglot_visit_NodeScrambler$object *, jlong);

// Virtual methods
extern jboolean _jc_polyglot_visit_NodeScrambler$method$coinFlip$ace8a74663ced208(_jc_env *, struct _jc_polyglot_visit_NodeScrambler$object *);
extern jlong _jc_polyglot_visit_NodeScrambler$method$getSeed$341b3bd5db0dc034(_jc_env *, struct _jc_polyglot_visit_NodeScrambler$object *);
extern struct _jc_object *_jc_polyglot_visit_NodeScrambler$method$override$1e05b257002785f7(_jc_env *, struct _jc_polyglot_visit_NodeScrambler$object *, struct _jc_object *);
extern struct _jc_object *_jc_polyglot_visit_NodeScrambler$method$potentialScramble$d3650580c3f1494f(_jc_env *, struct _jc_polyglot_visit_NodeScrambler$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_polyglot_visit_NodeScrambler$method_info$coinFlip$ace8a74663ced208;
extern _jc_method _jc_polyglot_visit_NodeScrambler$method_info$getSeed$341b3bd5db0dc034;
extern _jc_method _jc_polyglot_visit_NodeScrambler$method_info$override$1e05b257002785f7;
extern _jc_method _jc_polyglot_visit_NodeScrambler$method_info$potentialScramble$d3650580c3f1494f;

// Static methods
extern struct _jc_java_lang_Class$object *_jc_polyglot_visit_NodeScrambler$method$class__24$57cd45dca0be1678(_jc_env *, struct _jc_java_lang_String$object *);

// Virtual methods structure
struct _jc_polyglot_visit_NodeScrambler$vmethods {
	jboolean	(*coinFlip$ace8a74663ced208)(_jc_env *, struct _jc_polyglot_visit_NodeScrambler$object *);
	jlong	(*getSeed$341b3bd5db0dc034)(_jc_env *, struct _jc_polyglot_visit_NodeScrambler$object *);
	struct _jc_object	*(*override$1e05b257002785f7)(_jc_env *, struct _jc_polyglot_visit_NodeScrambler$object *, struct _jc_object *);
	struct _jc_object	*(*potentialScramble$d3650580c3f1494f)(_jc_env *, struct _jc_polyglot_visit_NodeScrambler$object *, struct _jc_object *);
};

// Vtable
struct _jc_polyglot_visit_NodeScrambler$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_visit_NodeVisitor$vmethods	polyglot_visit_NodeVisitor;
	_jc_polyglot_visit_NodeScrambler$vmethods	polyglot_visit_NodeScrambler;
};

// Vtype
struct _jc_polyglot_visit_NodeScrambler$vtype {
	_jc_type			type;
	_jc_polyglot_visit_NodeScrambler$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_visit_NodeScrambler$sub_refs {
	struct _jc_polyglot_visit_NodeScrambler__24FirstPass$object	*fp;
	struct _jc_java_util_HashMap$object	*pairs;
	struct _jc_java_util_LinkedList$object	*nodes;
	struct _jc_java_util_LinkedList$object	*currentParents;
	struct _jc_java_util_Random$object	*ran;
	struct _jc_polyglot_util_CodeWriter$object	*cw;
};

// Reference instance fields (object)
struct _jc_polyglot_visit_NodeScrambler$refs {
    _jc_polyglot_visit_NodeScrambler$sub_refs	polyglot_visit_NodeScrambler;
    _jc_polyglot_visit_NodeVisitor$sub_refs	polyglot_visit_NodeVisitor;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_visit_NodeScrambler$sub_nonrefs {
	jlong	seed;
	jboolean	scrambled;
};

// Non-reference instance fields (object)
struct _jc_polyglot_visit_NodeScrambler$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_visit_NodeVisitor$sub_nonrefs	polyglot_visit_NodeVisitor;
    _jc_polyglot_visit_NodeScrambler$sub_nonrefs	polyglot_visit_NodeScrambler;
};

// Object instance structure
struct _jc_polyglot_visit_NodeScrambler$object {
	_jc_polyglot_visit_NodeScrambler$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_visit_NodeScrambler$vtype	*vtype;
	_jc_polyglot_visit_NodeScrambler$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_visit_NodeScrambler$vtype _jc_polyglot_visit_NodeScrambler$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_visit_NodeScrambler, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_visit_NodeScrambler$class_object;

#endif	/* _JC_polyglot_visit_NodeScrambler_H_ */

==> jc-1.4.6.tar.gz: polyglot/visit/NodeScrambler.h <==
// public class polyglot.visit.NodeScrambler

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class d56530f3adaadb75 polyglot_visit_NodeScrambler
// @dep_class 534db787197439f0 polyglot_visit_NodeVisitor

// header file dependencies
// @dep_header polyglot_visit_NodeVisitor

#include "polyglot/visit/NodeVisitor.h"

#ifndef _JC_polyglot_visit_NodeScrambler_H_
#define _JC_polyglot_visit_NodeScrambler_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_HashMap$object;
struct _jc_java_util_LinkedList$object;
struct _jc_java_util_Random$object;
struct _jc_polyglot_ast_Node$object;
struct _jc_polyglot_util_CodeWriter$object;
struct _jc_polyglot_visit_NodeScrambler__24FirstPass$object;

// Typedefs
typedef struct _jc_polyglot_visit_NodeScrambler$sub_refs	_jc_polyglot_visit_NodeScrambler$sub_refs;
typedef struct _jc_polyglot_visit_NodeScrambler$sub_nonrefs	_jc_polyglot_visit_NodeScrambler$sub_nonrefs;
typedef struct _jc_polyglot_visit_NodeScrambler$refs	_jc_polyglot_visit_NodeScrambler$refs;
typedef struct _jc_polyglot_visit_NodeScrambler$nonrefs	_jc_polyglot_visit_NodeScrambler$nonrefs;
typedef struct _jc_polyglot_visit_NodeScrambler$object	_jc_polyglot_visit_NodeScrambler$object;

typedef struct _jc_polyglot_visit_NodeScrambler$fields_struct	_jc_polyglot_visit_NodeScrambler$fields_struct;
typedef const struct _jc_polyglot_visit_NodeScrambler$vmethods	_jc_polyglot_visit_NodeScrambler$vmethods;
typedef const struct _jc_polyglot_visit_NodeScrambler$vtable	_jc_polyglot_visit_NodeScrambler$vtable;
typedef const struct _jc_polyglot_visit_NodeScrambler$vtype	_jc_polyglot_visit_NodeScrambler$vtype;

// Class fields structure
struct _jc_polyglot_visit_NodeScrambler$fields_struct {
	struct _jc_java_lang_Class$object	*class__24polyglot__24ast__24Block;
	struct _jc_java_lang_Class$object	*class__24polyglot__24ast__24Catch;
	struct _jc_java_lang_Class$object	*class__24polyglot__24ast__24ClassDecl;
	struct _jc_java_lang_Class$object	*class__24polyglot__24ast__24ClassMember;
	struct _jc_java_lang_Class$object	*class__24polyglot__24ast__24Expr;
	struct _jc_java_lang_Class$object	*class__24polyglot__24ast__24Formal;
	struct _jc_java_lang_Class$object	*class__24polyglot__24ast__24Import;
	struct _jc_java_lang_Class$object	*class__24polyglot__24ast__24LocalDecl;
	struct _jc_java_lang_Class$object	*class__24polyglot__24ast__24Node;
	struct _jc_java_lang_Class$object	*class__24polyglot__24ast__24Stmt;
	struct _jc_java_lang_Class$object	*class__24polyglot__24ast__24TypeNode;
};
extern _jc_polyglot_visit_NodeScrambler$fields_struct _jc_polyglot_visit_NodeScrambler$class_fields;

// Constructors
extern void _jc_polyglot_visit_NodeScrambler$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_polyglot_visit_NodeScrambler$object *) _JC_JCNI_ATTR;
extern void _jc_polyglot_visit_NodeScrambler$method$_init$8de6a0a3bec04d2a(_jc_env *, struct _jc_polyglot_visit_NodeScrambler$object *, jlong) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_polyglot_visit_NodeScrambler$method$coinFlip$ace8a74663ced208(_jc_env *, struct _jc_polyglot_visit_NodeScrambler$object *) _JC_JCNI_ATTR;
extern jlong _jc_polyglot_visit_NodeScrambler$method$getSeed$341b3bd5db0dc034(_jc_env *, struct _jc_polyglot_visit_NodeScrambler$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_polyglot_visit_NodeScrambler$method$override$1e05b257002785f7(_jc_env *, struct _jc_polyglot_visit_NodeScrambler$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_polyglot_visit_NodeScrambler$method$potentialScramble$d3650580c3f1494f(_jc_env *, struct _jc_polyglot_visit_NodeScrambler$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_polyglot_visit_NodeScrambler$method_info$coinFlip$ace8a74663ced208;
extern _jc_method _jc_polyglot_visit_NodeScrambler$method_info$getSeed$341b3bd5db0dc034;
extern _jc_method _jc_polyglot_visit_NodeScrambler$method_info$override$1e05b257002785f7;
extern _jc_method _jc_polyglot_visit_NodeScrambler$method_info$potentialScramble$d3650580c3f1494f;

// Static methods
extern struct _jc_java_lang_Class$object *_jc_polyglot_visit_NodeScrambler$method$class__24$57cd45dca0be1678(_jc_env *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_polyglot_visit_NodeScrambler$vmethods {
	jboolean	(*coinFlip$ace8a74663ced208)(_jc_env *, struct _jc_polyglot_visit_NodeScrambler$object *) _JC_JCNI_ATTR;
	jlong	(*getSeed$341b3bd5db0dc034)(_jc_env *, struct _jc_polyglot_visit_NodeScrambler$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*override$1e05b257002785f7)(_jc_env *, struct _jc_polyglot_visit_NodeScrambler$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*potentialScramble$d3650580c3f1494f)(_jc_env *, struct _jc_polyglot_visit_NodeScrambler$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_polyglot_visit_NodeScrambler$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_visit_NodeVisitor$vmethods	polyglot_visit_NodeVisitor;
	_jc_polyglot_visit_NodeScrambler$vmethods	polyglot_visit_NodeScrambler;
};

// Vtype
struct _jc_polyglot_visit_NodeScrambler$vtype {
	_jc_type			type;
	_jc_polyglot_visit_NodeScrambler$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_visit_NodeScrambler$sub_refs {
	struct _jc_polyglot_visit_NodeScrambler__24FirstPass$object	*fp;
	struct _jc_java_util_HashMap$object	*pairs;
	struct _jc_java_util_LinkedList$object	*nodes;
	struct _jc_java_util_LinkedList$object	*currentParents;
	struct _jc_java_util_Random$object	*ran;
	struct _jc_polyglot_util_CodeWriter$object	*cw;
};

// Reference instance fields (object)
struct _jc_polyglot_visit_NodeScrambler$refs {
    _jc_polyglot_visit_NodeScrambler$sub_refs	polyglot_visit_NodeScrambler;
    _jc_polyglot_visit_NodeVisitor$sub_refs	polyglot_visit_NodeVisitor;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_visit_NodeScrambler$sub_nonrefs {
	jlong	seed;
	jboolean	scrambled;
};

// Non-reference instance fields (object)
struct _jc_polyglot_visit_NodeScrambler$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_visit_NodeVisitor$sub_nonrefs	polyglot_visit_NodeVisitor;
    _jc_polyglot_visit_NodeScrambler$sub_nonrefs	polyglot_visit_NodeScrambler;
};

// Object instance structure
struct _jc_polyglot_visit_NodeScrambler$object {
	_jc_polyglot_visit_NodeScrambler$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_visit_NodeScrambler$vtype	*vtype;
	_jc_polyglot_visit_NodeScrambler$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_visit_NodeScrambler$vtype _jc_polyglot_visit_NodeScrambler$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_visit_NodeScrambler, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_visit_NodeScrambler$class_object;

#endif	/* _JC_polyglot_visit_NodeScrambler_H_ */
